pub struct ActorEnvVarClient { /* private fields */ }Expand description
Client for a specific environment variable of an Actor version.
Implementations
Sourceimpl ActorEnvVarClient
impl ActorEnvVarClient
Sourcepub async fn get(&self) -> ApifyClientResult<Option<ActorEnvVar>>
pub async fn get(&self) -> ApifyClientResult<Option<ActorEnvVar>>
Fetches the environment variable, or None if it does not exist.
Sourcepub async fn update(
&self,
env_var: &ActorEnvVar,
) -> ApifyClientResult<ActorEnvVar>
pub async fn update( &self, env_var: &ActorEnvVar, ) -> ApifyClientResult<ActorEnvVar>
Updates the environment variable.
Sourcepub async fn delete(&self) -> ApifyClientResult<()>
pub async fn delete(&self) -> ApifyClientResult<()>
Deletes the environment variable.