pub struct ActorVersionClient { /* private fields */ }Expand description
Client for a specific Actor version.
Implementations
Sourceimpl ActorVersionClient
impl ActorVersionClient
Sourcepub async fn get(&self) -> ApifyClientResult<Option<ActorVersion>>
pub async fn get(&self) -> ApifyClientResult<Option<ActorVersion>>
Fetches the version, or None if it does not exist.
Sourcepub async fn update<T: Serialize>(
&self,
new_fields: &T,
) -> ApifyClientResult<ActorVersion>
pub async fn update<T: Serialize>( &self, new_fields: &T, ) -> ApifyClientResult<ActorVersion>
Updates the version with the given fields.
Sourcepub async fn delete(&self) -> ApifyClientResult<()>
pub async fn delete(&self) -> ApifyClientResult<()>
Deletes the version.
Sourcepub fn env_var(&self, name: &str) -> ActorEnvVarClient
pub fn env_var(&self, name: &str) -> ActorEnvVarClient
Returns a client for a specific environment variable of this version.
Sourcepub fn env_vars(&self) -> ActorEnvVarCollectionClient
pub fn env_vars(&self) -> ActorEnvVarCollectionClient
Returns a client for this version’s environment variable collection.