pub struct GetRecordsOptions {
pub collection: Option<String>,
pub prefix: Option<String>,
pub signature: Option<String>,
}Expand description
Options for downloading all records as a ZIP archive via
KeyValueStoreClient::get_records.
Covers the spec query parameters of GET /v2/key-value-stores/{storeId}/records.
Fields
collection: Option<String>Only include records belonging to this collection from the store schema.
prefix: Option<String>Only include records whose key starts with this prefix.
signature: Option<String>URL-signing signature granting access to a private store’s records.