pub struct ScheduleClient { /* private fields */ }Expand description
Client for a specific schedule.
Implementations
Sourceimpl ScheduleClient
impl ScheduleClient
Sourcepub async fn get(&self) -> ApifyClientResult<Option<Schedule>>
pub async fn get(&self) -> ApifyClientResult<Option<Schedule>>
Fetches the schedule, or None if it does not exist.
Sourcepub async fn update<T: Serialize>(
&self,
new_fields: &T,
) -> ApifyClientResult<Schedule>
pub async fn update<T: Serialize>( &self, new_fields: &T, ) -> ApifyClientResult<Schedule>
Updates the schedule with the given fields.
Sourcepub async fn delete(&self) -> ApifyClientResult<()>
pub async fn delete(&self) -> ApifyClientResult<()>
Deletes the schedule.
Sourcepub async fn get_log(&self) -> ApifyClientResult<Option<String>>
pub async fn get_log(&self) -> ApifyClientResult<Option<String>>
Fetches the schedule’s invocation log as text, or None if not available.