Build

Struct Build 

pub struct Build {
    pub id: String,
    pub act_id: Option<String>,
    pub status: Option<String>,
    pub started_at: Option<DateTime<Utc>>,
    pub finished_at: Option<DateTime<Utc>>,
    pub build_number: Option<String>,
    pub image_digest: Option<String>,
    pub extra: Extra,
}
A build of an Actor.

Fields

id: String

Unique build ID.

act_id: Option<String>

ID of the Actor that was built.

status: Option<String>

Current build status.

started_at: Option<DateTime<Utc>>

When the build started.

finished_at: Option<DateTime<Utc>>

When the build finished.

build_number: Option<String>

Build number, e.g. 0.1.2.

image_digest: Option<String>

Digest of the built Docker image manifest, without the sha256: prefix. Compare the digests of two builds to find out whether their image contents differ. None if the digest is not available (e.g. the build has not finished, or is older than when the API started recording it).

extra: Extra

Any other fields returned by the API.

Implementations

Source

impl Build

pub fn is_terminal(&self) -> bool

Returns true if the build has reached a terminal state.