pub struct RequestQueueOperationInfo {
pub request_id: String,
pub was_already_present: bool,
pub was_already_handled: bool,
}Expand description
Result of adding (or updating) a request in a queue.
Fields
request_id: StringID of the request that was added or updated.
was_already_present: boolWhether the request was already present in the queue.
was_already_handled: boolWhether the request had already been handled.