pub struct RequestQueueRequestsPage {
pub limit: i64,
pub exclusive_start_id: Option<String>,
pub cursor: Option<String>,
pub next_cursor: Option<String>,
pub items: Vec<RequestQueueRequest>,
}Expand description
A page of requests returned by GET /v2/request-queues/{queueId}/requests (cursor-based
pagination over every request in the queue, as opposed to RequestQueueHead’s unlocked
peek at the head).
Fields
limit: i64Maximum number of requests returned for this request.
exclusive_start_id: Option<String>ID of the last request of the previous page. Deprecated by the API in favour of cursor.
cursor: Option<String>Cursor identifying the current page.
next_cursor: Option<String>Cursor to pass as cursor to fetch the next page; absent on the last page.
items: Vec<RequestQueueRequest>The requests of this page.