pub struct Schedule {
pub id: String,
pub user_id: Option<String>,
pub name: Option<String>,
pub cron_expression: Option<String>,
pub is_enabled: Option<bool>,
pub extra: Extra,
}Expand description
A schedule that triggers Actor or task runs on a cron expression.
Fields
id: StringUnique schedule ID.
user_id: Option<String>ID of the owner.
name: Option<String>Technical name of the schedule.
cron_expression: Option<String>The cron expression that determines when the schedule fires.
is_enabled: Option<bool>Whether the schedule is currently enabled.
extra: ExtraAny other fields returned by the API.